===============================
bioinfo
===============================

.. image:: https://badge.fury.io/py/bioinfo.png
    :target: http://badge.fury.io/py/bioinfo

.. image:: https://travis-ci.org/luizirber/bioinfo.png?branch=master
        :target: https://travis-ci.org/luizirber/bioinfo

.. image:: https://pypip.in/d/bioinfo/badge.png
        :target: https://crate.io/packages/bioinfo?version=latest


Bioinformatics scripts

Features
--------

* TODO

Requirements
------------

- Python >= 2.6 or >= 3.3

License
-------

BSD licensed. See the bundled `LICENSE <https://github.com/luizirber/bioinfo/blob/master/LICENSE>`_ file for more details.
